@@ -1,12 +1,12 @@
-import os
 import uuid
-from typing import Optional, Union
-from io import BytesIO, StringIO
 import json
-import pathlib
+
+from typing import Optional
+from io import BytesIO
+from .basemodel import BaseModel
 
 
-class Attachment:
+class Attachment(BaseModel):
     def __init__(self,
                  file_name: str,
                  mime_type: str,
@@ -24,28 +24,21 @@ class Attachment:
         if (not isinstance(content, str)) and (not isinstance(content, bytes)):
             self.content = json.dumps(self.content, default=lambda o: o.__dict__, sort_keys=False, indent=4)
 
-        self.size = self._get_size(content)
         self.id = str(uuid.uuid4())
 
-    def _get_size(self, content):
-        if self.file_path:
-            return os.path.getsize(self.file_path)
-        elif content:
-            return len(content)
-        else:
-            return 0
-
     def get_id(self) -> str:
         return self.id
 
     def get_for_upload(self) -> BytesIO:
         if self.file_path:
-            return pathlib.Path(os.path.abspath(self.file_path))
+            with open(self.file_path, "rb") as fc:
+                content = BytesIO(fc.read())
         else:
             if isinstance(self.content, str):
-                content = BytesIO(self.content.encode('utf-8'))
+                content = BytesIO(bytes(self.content, 'utf-8'))
             elif isinstance(self.content, bytes):
                 content = BytesIO(self.content)
         content.name = self.file_name
         content.mime = self.mime_type
+
         return content
